@@ -25,7 +25,8 @@ import os
 import shutil
 import itertools
 
-from ubuntuone.oauthdesktop.main import Login, LoginProcessor
+from ubuntu_sso import DBUS_IFACE_CRED_NAME
+from ubuntu_sso.main import SSOCredentials
 from ubuntuone.syncdaemon import (
     config,
     action_queue,
@@ -35,19 +36,25 @@ from ubuntuone.syncdaemon import (
     volume_manager,
     main,
     local_rescan,
+    logger,
 )
 from ubuntuone.syncdaemon.dbus_interface import (
     DBusInterface,
     DBusExposedObject,
     NM_STATE_CONNECTED,
     NM_STATE_DISCONNECTED,
-    DBUS_IFACE_AUTH_NAME,
 )
 from twisted.internet import defer
 from twisted.python import failure
 from twisted.trial.unittest import TestCase as TwistedTestCase
 from zope.interface import implements
-from oauth import oauth
+
+
+FAKED_CREDENTIALS = {'consumer_key': 'faked_consumer_key',
+                     'consumer_secret': 'faked_consumer_secret',
+                     'token': 'faked_token',
+                     'token_secret': 'faked_token_secret',
+                     'token_name': 'Test me please'}
 
 
 @contextlib.contextmanager
@@ -62,21 +69,11 @@ def environ(env_var, new_value):
         os.environ[env_var] = old_value
 
 
-class FakeOAuthClient(object):
-    """ Fake OAuthClient"""
-
-    def __init__(self, realm):
-        """ create the instance. """
-        self.realm = realm
-        self.consumer = oauth.OAuthConsumer('ubuntuone', 'hammertime')
-
-    def get_access_token(self):
-        """ returns a Token"""
-        return 'a token'
-
-
 class FakeHashQueue(object):
     """A fake hash queue"""
+    def __init__(self, eq):
+        self.eq = eq
+
     def empty(self):
         """are we empty? sure we are"""
         return True
@@ -89,6 +86,12 @@ class FakeHashQueue(object):
         """ length is 0. we are empty, right?"""
         return 0
 
+    def insert(self, path, mdid):
+        """Fake insert."""
+        self.eq.push('HQ_HASH_NEW', path=path, hash='',
+                     crc32='', size=0, stat=os.stat(path))
+
+
 
 class FakeMark(object):
     """A fake Mark Shuttleworth..."""
@@ -98,13 +101,71 @@ class FakeMark(object):
 
 class FakeDBusInterface(object):
     """A fake DBusInterface..."""
+
     def shutdown(self, with_restart=False):
         """...that only knows how to go away"""
 
+    def _request_token(self):
+        """Return a token which is a fixed set of credentials."""
+        return FAKED_CREDENTIALS
+
+
+class FakeActionQueue(object):
+    """Stub implementation."""
+
+    implements(interfaces.IActionQueue)
+
+    def __init__(self, eq, *args, **kwargs):
+        """ Creates the instance """
+        self.eq = self.event_queue = eq
+        self.uploading = {}
+        self.downloading = {}
+        self.uuid_map = action_queue.DeferredMap()
+        self.content_queue = action_queue.ContentQueue('CONTENT_QUEUE', self)
+        self.meta_queue = action_queue.RequestQueue('META_QUEUE', self)
+
+        # throttling attributes
+        self.readLimit = None
+        self.writeLimit = None
+        self.throttling_enabled = False
+
+    def connect(self, host=None, port=None, user_ssl=False):
+        """Just send connect!."""
+        self.eq.push('SYS_CONNECTION_MADE')
+
+    def enable_throttling(self):
+        """We have throttling enabled now."""
+        self.throttling_enabled = True
+
+    def disable_throttling(self):
+        """We have throttling disabled now."""
+        self.throttling_enabled = False
+
+    def answer_share(self, share_id, answer):
+        """Send the event."""
+        self.eq.push('AQ_ANSWER_SHARE_OK', share_id, answer)
+
+    def delete_share(self, share_id):
+        """Stub."""
+
+    def disconnect(self, *a, **k):
+        """Stub implementation."""
+
+    cancel_download = cancel_upload = download = upload = make_dir = disconnect
+    make_file = move = unlink = list_shares = disconnect
+    list_volumes = create_share = inquire_free_space =  disconnect
+    inquire_account_info = delete_volume = change_public_access = disconnect
+    query_volumes = get_delta = rescan_from_scratch = disconnect
+    node_is_with_queued_move = disconnect
+
 
 class FakeMain(main.Main):
     """ A fake Main class to setup the tests """
 
+    _fake_AQ_class = FakeActionQueue
+    _fake_AQ_params = ()
+    _sync_class = None
+
     # don't call Main.__init__ we take care of creating a fake main and
     # all its attributes. pylint: disable-msg=W0231
     def __init__(self, root_dir, shares_dir, data_dir, partials_dir):
@@ -115,24 +176,25 @@ class FakeMain(main.Main):
         self.shares_dir = shares_dir
         self.partials_dir = partials_dir
         self.shares_dir_link = os.path.join(self.root_dir, 'Shared With Me')
-        self.realm = 'http://test.ubuntuone.com'
-        self.oauth_client = FakeOAuthClient(self.realm)
         self.vm = volume_manager.VolumeManager(self)
         self.fs = fs_manager.FileSystemManager(self.data_dir,
                                                self.partials_dir, self.vm)
         self.event_q = event_queue.EventQueue(self.fs)
         self.fs.register_eq(self.event_q)
-        self.action_q = FakeActionQueue(self.event_q, main=self)
+        self.action_q = self._fake_AQ_class(self.event_q, self,
+                                            *self._fake_AQ_params)
         self.state_manager = main.StateManager(self, 2)
+        if self._sync_class is not None:
+            self.sync = self._sync_class(self)
         self.event_q.subscribe(self.vm)
         self.vm.init_root()
-        self.hash_q = FakeHashQueue()
+        self.hash_q = FakeHashQueue(self.event_q)
         self.mark = FakeMark()
         self.dbus_iface = FakeDBusInterface()
         self.lr = local_rescan.LocalRescan(self.vm, self.fs,
                                            self.event_q, self.action_q)
 
-    def _connect_aq(self, token):
+    def _connect_aq(self, _):
         """Connect the fake action queue."""
         self.action_q.connect()
 
@@ -140,10 +202,6 @@ class FakeMain(main.Main):
         """Disconnect the fake action queue."""
         self.action_q.disconnect()
 
-    def get_access_token(self):
-        """Fake get token."""
-        return None
-
     def check_version(self):
         """Check the client protocol version matches that of the server."""
         self.event_q.push('SYS_PROTOCOL_VERSION_OK')
@@ -284,6 +342,9 @@ class DBusTwistedTestCase(BaseTwistedTestCase):
         dbus.service.BusName.__del__ = lambda _: None
         self.dbus_iface = DBusInterface(self.bus, self.main,
                                         system_bus=self.bus)
+        # token is a fixed set of credentials
+        self.dbus_iface._request_token = lambda: FAKED_CREDENTIALS
+
         self.main.dbus_iface = self.dbus_iface
         self.busName = self.dbus_iface.busName
         self.bus.set_exit_on_disconnect(False)
@@ -341,105 +402,6 @@ class DBusTwistedTestCase(BaseTwistedTestCase):
             return defer.succeed(True)
 
 
-class FakeActionQueue(object):
-    """Stub implementation."""
-
-    implements(interfaces.IActionQueue)
-
-    def __init__(self, eq, *args, **kwargs):
-        """ Creates the instance """
-        self.eq = self.event_queue = eq
-        self.uploading = {}
-        self.downloading = {}
-        # pylint: disable-msg=C0103
-        class UUID_Map(object):
-            """mock uuid map"""
-            def set(self, *args):
-                """mock set method"""
-                pass
-
-        self.uuid_map = UUID_Map()
-        self.content_queue = action_queue.ContentQueue('CONTENT_QUEUE', self)
-        self.meta_queue = action_queue.RequestQueue('META_QUEUE', self)
-
-        # throttling attributes
-        self.readLimit = None
-        self.writeLimit = None
-        self.throttling_enabled = False
-
-    def connect(self, host=None, port=None, user_ssl=False):
-        """Stub implementation."""
-        self.eq.push('SYS_CONNECTION_MADE')
-
-    def disconnect(self):
-        """Stub implementation."""
-
-    def enable_throttling(self):
-        """Stub implementation."""
-        self.throttling_enabled = True
-
-    def disable_throttling(self):
-        """Stub implementation."""
-        self.throttling_enabled = False
-
-    def cancel_download(self, share_id, node_id):
-        """Stub implementation."""
-
-    def cancel_upload(self, share_id, node_id):
-        """Stub implementation."""
-
-    def download(self, share_id, node_id, server_hash, fileobj):
-        """Stub implementation."""
-
-    def upload(self, share_id, node_id, previous_hash, hash, crc32,
-               size, deflated_size, fileobj):
-        """Stub implementation."""
-
-    def make_file(self, share_id, parent_id, name, marker):
-        """Stub implementation."""
-
-    def make_dir(self, share_id, parent_id, name, marker):
-        """Stub implementation."""
-
-    def move(self, share_id, node_id, old_parent_id, new_parent_id, new_name):
-        """Stub implementation."""
-
-    def unlink(self, share_id, node_id):
-        """Stub implementation."""
-
-    def query(self, items):
-        """Stub implementation."""
-
-    def listdir(self, share_id, node_id, server_hash, fileobj):
-        """Stub implementation."""
-
-    def list_shares(self):
-        """Stub implementation."""
-
-    def list_volumes(self):
-        """ stub implementation """
-        pass
-
-    def answer_share(self, share_id, answer):
-        """Stub implementation."""
-        self.eq.push('AQ_ANSWER_SHARE_OK', share_id, answer)
-
-    def create_share(self, *args):
-        """ sutb implementation """
-
-    def inquire_free_space(self, share_id):
-        """Stub implementation."""
-
-    def inquire_account_info(self):
-        """Stub implementation."""
-
-    def delete_volume(self, volume_id):
-        """Stub implementation."""
-
-    def change_public_access(self, share_id, node_id, is_public):
-        """Stub implementation."""
-
-
 class MementoHandler(logging.Handler):
     """ A handler class which store logging records in a list """
 
@@ -447,11 +409,43 @@ class MementoHandler(logging.Handler):
         """ Create the instance, and add a records attribute. """
         logging.Handler.__init__(self, *args, **kwargs)
         self.records = []
+        self.debug = False
 
     def emit(self, record):
         """ Just add the record to self.records. """
         self.records.append(record)
 
+    def check(self, level, *msgs):
+        """Verifies that the msgs are logged in the specified level."""
+        for rec in self.records:
+            if rec.levelno == level and all(m in rec.message for m in msgs):
+                return True
+        if self.debug:
+            recorded =  [(logging.getLevelName(r.levelno), r.message)
+                         for r in self.records]
+            print "Memento messages:", recorded
+        return False
+
+    def check_debug(self, *msgs):
+        """Shortcut for checking in DEBUG."""
+        return self.check(logging.DEBUG, *msgs)
+
+    def check_info(self, *msgs):
+        """Shortcut for checking in INFO."""
+        return self.check(logging.INFO, *msgs)
+
+    def check_warning(self, *msgs):
+        """Shortcut for checking in WARNING."""
+        return self.check(logging.WARNING, *msgs)
+
+    def check_error(self, *msgs):
+        """Shortcut for checking in ERROR."""
+        return self.check(logging.ERROR, *msgs)
+
+    def check_note(self, *msgs):
+        """Shortcut for checking in NOTE."""
+        return self.check(logger.NOTE, *msgs)
+
 
 class FakeNetworkManager(DBusExposedObject):
     """ A fake NetworkManager that only emits StatusChanged signal. """
@@ -528,9 +522,6 @@ class FakeVolumeManager(object):
         """Add udf to the udfs dict."""
         self.udfs[udf.id] = udf
 
-    def handle_SYS_ROOT_RECEIVED(self, root_id):
-        """Do nothing."""
-
     def share_deleted(self, _):
         """Do nothing."""
 
@@ -559,12 +550,11 @@ class FakeVolumeManager(object):
 
 
 # OAuth stubs
-class FakeLoginProcessor(LoginProcessor):
+class FakeLoginProcessor(object):
     """Stub login processor."""
 
     def __init__(self, dbus_object):
         """Initialize the login processor."""
-        LoginProcessor.__init__(self, dbus_object, use_libnotify=False)
         self.next_login_cb = None
 
     def login(self, realm, consumer_key, error_handler=None,
@@ -594,13 +584,13 @@ class FakeLoginProcessor(LoginProcessor):
         self.next_login_cb = (callback, args)
 
 
-class FakeLogin(Login):
+class FakeLogin(SSOCredentials):
     """Stub Object which listens for D-Bus OAuth requests"""
 
     def __init__(self, bus):
         """Initiate the object."""
         self.bus = bus
-        self.busName = dbus.service.BusName(DBUS_IFACE_AUTH_NAME, bus=self.bus)
+        self.busName = dbus.service.BusName(DBUS_IFACE_CRED_NAME, bus=self.bus)
         # bypass the parent class __init__ as it has the path hardcoded
         # and we can't use '/' as the path, as we are already using it
         # for syncdaemon. pylint: disable-msg=W0233,W0231
@@ -653,7 +643,7 @@ class Listener(object):
 class DummyClass(object):
     """Dummy class, does nothing."""
 
-    def __getattribute__(self, name):
+    def __getattr__(self, name):
         """Any attribute is a no-op."""
         return lambda *args, **kwargs: None
 
