@@ -51,6 +51,11 @@ class BaseEQTestCase(testcase.BaseTwistedTestCase):
         self.eq = event_queue.EventQueue(self.fs)
         self.fs.register_eq(self.eq)
 
+        # add a Memento handler to the logger
+        self.log_handler = testcase.MementoHandler()
+        self.log_handler.setLevel(logging.DEBUG)
+        self.eq.log.addHandler(self.log_handler)
+
     def tearDown(self):
         """Clean up the tests."""
         for listener in self.eq._listeners:
@@ -185,19 +190,31 @@ class PushTests(BaseEQTestCase):
         self.assertRaises(TypeError, self.eq.push, "FS_FILE_CREATE", 1, 2)
 
         # approved by EQ, but the listener has a wrong signature
-        # this is logged as an error/exception, so we hook to the logger
-        handler = testcase.MementoHandler()
-        handler.setLevel(logging.ERROR)
-        self.eq.log.addHandler(handler)
-
+        # this is logged as an error/exception
         self.eq.push("FS_FILE_CREATE", 1)
-        self.assertEquals(1, len(handler.records))
-        self.assertEquals('FS_FILE_CREATE', handler.records[0].args[0])
-        self.assertEquals(Create, type(handler.records[0].args[1]))
+        self.assertTrue(self.log_handler.check_error('FS_FILE_CREATE',
+                                                     'Create object'))
 
-        self.eq.log.removeHandler(handler)
         self.eq.unsubscribe(c)
 
+    def test_log_pushing_data(self):
+        """Pushed event and info should be logged."""
+        self.eq.push("AQ_QUERY_ERROR", 'item', error='err')
+        self.assertTrue(self.log_handler.check_debug(
+            "push_event: AQ_QUERY_ERROR, args:('item',), kw:{'error': 'err'}"))
+
+    def test_log_delete_in_info(self):
+        """Pushed any deletion event should be logged in info."""
+        self.eq.push("FS_DIR_DELETE", 'path')
+        self.assertTrue(self.log_handler.check_info(
+                        "push_event: FS_DIR_DELETE"))
+
+    def test_log_pushing_private_data(self):
+        """SYS_USER_CONNECT event info must not be logged."""
+        self.eq.push("SYS_USER_CONNECT", access_token='foo')
+        self.assertTrue(self.log_handler.check_debug(
+            "push_event: SYS_USER_CONNECT, args:*, kw:*"))
+
 
 class PushTestsWithCallback(BaseEQTestCase):
     """Test the error handling in the event distribution machinery."""
