@@ -51,7 +51,10 @@ def hash_hack_run(self):
     """Function to hack the hash class to avoid it processing the requests."""
     while True:
         info = self.queue.get()
-        path, mdid = info
+        try:
+            path, mdid = info
+        except TypeError:
+            break
         self.hashing = path
 
 
@@ -93,6 +96,7 @@ class DownloadFinishedTests(TwistedTestCase):
     def tearDown(self):
         """tear down the test."""
         hash_queue._Hasher.run = self._original_hash_run
+        self.hq.shutdown()
 
     def insert_in_hq(self, path, node_id):
         """Inserts something in HQ and waits that thread."""
