@@ -1586,7 +1586,9 @@ class BadStateTests(TwistedBase):
         # start a put file, and assume we got interrupted (no server hash)
         pathhash = self._hash(path)
         self.fsm.set_by_mdid(mdid, local_hash=pathhash, crc32='foo')
-        self.fsm.refresh_stat(path)
+        mdobj = self.fsm.fs[mdid]
+        mdobj["stat"] = os.lstat(path)
+        self.fsm.fs[mdid] = mdobj
 
         def check(_):
             """Compare predictable args, and check fh factory."""
@@ -2070,6 +2072,13 @@ class BadStateTests(TwistedBase):
         self.startTest(check)
         return self.deferred
 
+    def test_check_stat_None(self):
+        """Test check_stat with oldstat = None."""
+        # create the file in metadata
+        path = os.path.join(self.share.path, "a_file")
+        self.fsm.create(path, self.share.volume_id, is_dir=False)
+        self.assertTrue(self.lr.check_stat(path, None))
+
 
 class RootBadStateTests(TwistedBase):
     """Test what happens with volume roots left in a bad state last time."""
