@@ -21,6 +21,7 @@
 from __future__ import with_statement
 
 import copy
+from inspect import getmembers, getargspec, ismethod
 import logging
 import os
 import shutil
@@ -43,13 +44,36 @@ from ubuntuone.syncdaemon.filesystem_manager import FileSystemManager
 from ubuntuone.syncdaemon.fsm import fsm as fsm_module
 from ubuntuone.syncdaemon.sync import FSKey, Sync, SyncStateMachineRunner
 from ubuntuone.syncdaemon.volume_manager import Share
-from ubuntuone.syncdaemon.event_queue import EventQueue
+from ubuntuone.syncdaemon.event_queue import EventQueue, EVENTS
 from ubuntuone.storageprotocol.request import ROOT
 from ubuntuone.storageprotocol import delta
 from ubuntuone.syncdaemon.marker import MDMarker
 
 DBusInterface.test = True
 
+
+class TestSyncClassAPI(unittest.TestCase):
+    """Tests that make sure the Sync class has the correct API."""
+
+    def test_error_handle_signatures(self):
+        """Make sure signatures match for the error handlers.
+
+        Each handle_<EVENT> should map to an EVENT in event_queue and have the
+        same signature.
+        """
+        for k in [k for k in dict(getmembers(Sync)) if k.startswith('handle_')]:
+            handler = getattr(Sync, k, None)
+            # it must be a method
+            self.assertTrue(ismethod(handler))
+            event = EVENTS.get(k.replace('handle_', ''))
+            # there must be a matching EVENT
+            self.assertNotEqual(event, None)
+            spec = getargspec(handler).args[1::]
+            # the argspec must also match (same order same variable names)
+            self.assertEqual(list(event),spec,
+                "Handler %s args do not match event args %s" % (k, event))
+
+
 class FSKeyTestCase(BaseTwistedTestCase):
     """ Base test case for FSKey """
 
@@ -566,7 +590,8 @@ class TestSync(BaseSync):
         somepath = os.path.join(self.root, 'somepath')
         self.fsm.create(somepath, '', node_id='node_id')
 
-        self.sync.handle_AQ_MOVE_ERROR('', 'node_id', 'parent', 'error')
+        self.sync.handle_AQ_MOVE_ERROR('', 'node_id', 'old_parent_id',
+                                       'new_parent_id', 'new_name', 'error')
         self.assertEqual(called[1:], ['AQ_MOVE_ERROR', {}, '', 'node_id'])
 
     def test_AQ_MOVE_ERROR_no_node(self):
@@ -576,7 +601,8 @@ class TestSync(BaseSync):
         self.patch(SyncStateMachineRunner, 'clean_move_limbo',
                    lambda *a: called.extend(a))
 
-        self.sync.handle_AQ_MOVE_ERROR('', 'node_id', 'parent', 'error')
+        self.sync.handle_AQ_MOVE_ERROR('', 'node_id', 'old_parent_id',
+                                       'new_parent_id', 'new_name', 'error')
         self.assertEqual(called[1:], ['AQ_MOVE_ERROR', {}, '', 'node_id'])
 
 
