@@ -19,6 +19,7 @@
 import os
 import uuid
 
+from dbus.exceptions import DBusException
 from ubuntuone.syncdaemon import (
     dbus_interface,
     event_queue,
@@ -26,7 +27,7 @@ from ubuntuone.syncdaemon import (
     volume_manager,
     states,
 )
-from tests.syncdaemon.test_dbus import FakeCommand
+from tests.syncdaemon.test_dbus import FakeCommand, EmptyCommand
 from contrib.testing.testcase import (
     DBusTwistedTestCase,
 )
@@ -299,23 +300,24 @@ class TestToolsBasic(TestToolsBase):
         d.addCallbacks(handler, self.fail)
         return d
 
+    @defer.inlineCallbacks
     def test_waiting_metadata(self):
         """Test SyncDaemonTool.waiting_metadata."""
         # inject the fake data
         self.action_q.meta_queue.waiting.extend([
                 FakeCommand("node_a_foo", "node_a_bar"),
                 FakeCommand("node_b_foo", "node_b_bar")])
-        d = self.tool.waiting_metadata()
-        def check(result):
-            """waiting_metadata reply handler."""
-            self.assertEquals(2, len(result))
-            # the second time we're called, the result should be reversed
-            node_a, node_b = result
-            self.assertEquals(str(FakeCommand("node_a_foo", "node_a_bar")),
-                              node_a)
-            self.assertEquals(str(FakeCommand("node_b_foo", "node_b_bar")),
-                              node_b)
-        return d
+        result = yield self.tool.waiting_metadata()
+
+        self.assertEquals(2, len(result))
+
+        pl = dict(share_id='node_a_foo', node_id='node_a_bar',
+                  other='', path='')
+        self.assertEqual(result[0], ('FakeCommand', pl))
+
+        pl = dict(share_id='node_b_foo', node_id='node_b_bar',
+                  other='', path='')
+        self.assertEqual(result[1], ('FakeCommand', pl))
 
     def test_waiting_content_schedule_next(self):
         """Test waiting_content and schedule_next"""
@@ -328,21 +330,23 @@ class TestToolsBasic(TestToolsBase):
         # inject the fake data
         self.action_q.content_queue.waiting.extend([
                 FakeCommand("", "node_id"),
-                FakeCommand("", "node_id_1")])
+                FakeCommand("", "node_id_1"),
+                EmptyCommand()])
 
         d = self.tool.waiting_content()
         self.second = False
         def handler(result):
             if self.second:
-                node_1, node = result
+                node_1, node, empty = result
             else:
-                node, node_1 = result
+                node, node_1, empty = result
             self.assertEquals(path, str(node['path']))
             self.assertEquals(path1, str(node_1['path']))
             self.assertEquals('', str(node['share']))
             self.assertEquals('', str(node_1['share']))
             self.assertEquals('node_id', str(node['node']))
             self.assertEquals('node_id_1', str(node_1['node']))
+            self.assertEquals(EmptyCommand.__name__, str(empty['operation']))
             self.assertTrue(result)
         d.addCallbacks(handler, self.fail)
         def second(_):
@@ -493,3 +497,71 @@ class TestToolsBasic(TestToolsBase):
         enabled = self.main.action_q.throttling_enabled
         self.assertFalse(enabled)
 
+    @defer.inlineCallbacks
+    def test_refresh_volumes(self):
+        """Test for refresh_volumes method."""
+        d = defer.Deferred()
+        def list_volumes():
+            """Stub list_volumes."""
+            d.callback(True)
+        self.main.action_q.list_volumes = list_volumes
+        yield self.tool.refresh_volumes()
+        yield d
+
+    @defer.inlineCallbacks
+    def test_rescan_from_scratch(self):
+        """Test for rescan_from_scratch method."""
+        suggested_path = u'~/ñoño'
+        udf = self._create_udf(uuid.uuid4(), 'node_id', suggested_path,
+                               subscribed=True)
+        yield self.main.vm.add_udf(udf)
+        d = defer.Deferred()
+        def rescan_from_scratch(volume_id):
+            """Stub method."""
+            d.callback(volume_id)
+        self.main.action_q.rescan_from_scratch = rescan_from_scratch
+        yield self.tool.rescan_from_scratch(udf.volume_id)
+        vol_id = yield d
+        self.assertEquals(vol_id, udf.volume_id)
+
+    @defer.inlineCallbacks
+    def test_rescan_from_scratch_missing_volume(self):
+        """Test for rescan_from_scratch method with a non-existing volume.."""
+        try:
+            yield self.tool.rescan_from_scratch('volume_id')
+        except DBusException, e:
+            self.assertEqual('org.freedesktop.DBus.Python.ubuntuone'
+                             '.syncdaemon.volume_manager.VolumeDoesNotExist',
+                             e.get_dbus_name())
+        else:
+            self.fail('Should fail with a non-existing volume.')
+
+    @defer.inlineCallbacks
+    def test_get_dirty_nodes(self):
+        """Test for get_dirty_nodes method."""
+        # create some nodes
+        path1 = os.path.join(self.root_dir, u'ñoño-1'.encode('utf-8'))
+        mdid1 = self.main.fs.create(path1, "")
+        path2 = os.path.join(self.root_dir, u'ñoño-2'.encode('utf-8'))
+        mdid2 = self.main.fs.create(path2, "")
+        path3 = os.path.join(self.root_dir, "path3")
+        mdid3 = self.main.fs.create(path3, "")
+        path4 = os.path.join(self.root_dir, "path4")
+        mdid4 = self.main.fs.create(path4, "")
+
+        # dirty some
+        self.main.fs.set_by_mdid(mdid2, dirty=True)
+        self.main.fs.set_by_mdid(mdid4, dirty=True)
+
+        # check
+        all_dirty = yield self.tool.get_dirty_nodes()
+        dirty_mdids = dict((n['mdid'], n) for n in all_dirty)
+        self.assertEqual(len(all_dirty), 2)
+        self.assertIn(mdid2, dirty_mdids)
+        self.assertIn(mdid4, dirty_mdids)
+        self.assertNotIn(mdid1, dirty_mdids)
+        self.assertNotIn(mdid3, dirty_mdids)
+        # check that path de/encoding is done correctly
+        self.assertEquals(repr(self.main.fs.get_by_mdid(mdid2).path),
+                          repr(dirty_mdids[mdid2]['path'].encode('utf-8')))
+
