@@ -654,7 +654,7 @@ class ActionQueue(ThrottlingStorageClientFactory, object):
     def have_sufficient_space_for_upload(self, share_id, upload_size):
         """Returns True if we have sufficient space for the given upload."""
         free = self.main.vm.get_free_space(share_id)
-        enough = free >= upload_size
+        enough = free is None or free >= upload_size
         if not enough:
             logger.info("Not enough space for upload %s bytes (available: %s)",
                         upload_size, free)
