@@ -642,14 +642,6 @@ class FileSystemManager(object):
         mdid = self._idx_node_id[(share_id, node_id)]
         self.set_by_mdid(mdid, **kwargs)
 
-    def refresh_stat(self, path):
-        """Refresh the stat of a md object."""
-        log_debug("refresh stat to path=%r", path)
-        mdid = self._idx_path[path]
-        mdobj = self.fs[mdid]
-        mdobj["stat"] = get_stat(path)
-        self.fs[mdid] = mdobj
-
     def move_file(self, new_share_id, path_from, path_to):
         """Move a file/dir from one point to the other."""
         path_from = os.path.normpath(path_from)
@@ -876,11 +868,19 @@ class FileSystemManager(object):
             raise InconsistencyError(msg)
         return partial_in_md
 
-    def _get_partial_path(self, mdobj):
+    def _get_partial_path(self, mdobj, trim=None):
         """Gets the path of the .partial file for a given mdobj"""
+        if trim is None and "partial_path" in mdobj["info"]:
+            return mdobj["info"]["partial_path"]
+
         path = self.get_abspath(mdobj['share_id'], mdobj['path'])
         partial_path = os.path.join(self.partials_dir, mdobj['mdid'] + '.u1partial')
         dirname, filename = os.path.split(path)
+
+        if trim is not None:
+            filename = filename[:-10*trim]
+            mdobj["info"]["partial_path"] = partial_path + '.' + filename
+
         return partial_path + '.' + filename
 
     def create_partial(self, node_id, share_id):
@@ -896,19 +896,33 @@ class FileSystemManager(object):
         mdobj = self.fs[mdid]
         is_dir = mdobj["is_dir"]
         path = self.get_abspath(mdobj['share_id'], mdobj['path'])
-        partial_path = self._get_partial_path(mdobj)
         with self._enable_share_write(share_id, os.path.dirname(path)):
             # if we don't have the dir yet, create it
             if is_dir and not os.path.exists(path):
                 self.eq.add_to_mute_filter("FS_DIR_CREATE", path)
                 os.mkdir(path)
 
-        # don't alert EQ, partials are in other directory, not watched
-        open(partial_path, "w").close()
         mdobj["info"]["last_partial_created"] = time.time()
         mdobj["info"]["is_partial"] = True
         self.fs[mdid] = mdobj
 
+        # create the partial path, trimming the name until fits
+        # in the filesystem
+        partial_path = self._get_partial_path(mdobj)
+        trim = 0
+        while True:
+            try:
+                # don't alert EQ, partials are in other directory, not watched
+                open(partial_path, "w").close()
+            except IOError, e:
+                if e.errno == errno.ENAMETOOLONG:
+                    trim += 1
+                    partial_path = self._get_partial_path(mdobj, trim=trim)
+                else:
+                    raise
+            else:
+                break
+
     def get_partial_for_writing(self, node_id, share_id):
         """Get a write-only fd to a partial file"""
         mdid = self._idx_node_id[(share_id, node_id)]
