@@ -359,6 +359,8 @@ class LocalRescan(object):
         - st_size: it changed in size, surely different content
         - st_mtime: the content could be different even having the same size
         """
+        if oldstat is None:
+            return True
         newstat = os.stat(fullname)
         different = (newstat.st_ino != oldstat.st_ino or
                      newstat.st_size != oldstat.st_size or
