@@ -23,7 +23,6 @@ import sys
 import os
 import zlib
 
-from itertools import imap
 from ubuntuone.logger import (
     LOGFOLDER,
     _DEBUG_LOG_LEVEL,
@@ -65,33 +64,36 @@ class mklog(object):
         self.zipped_desc = zlib.compress(desc, 9)
         self.logger = _logger
 
-    @property
-    def desc(self):
-        return zlib.decompress(self.zipped_desc)
-
     def _log(self, logger_func, *args):
-        """
-        Generalized form of the different logging functions.
-        """
-        logger_func(self.desc + " ".join(imap(str, args)))
+        """Generalized form of the different logging methods."""
+        desc = zlib.decompress(self.zipped_desc)
+        text = desc + args[0]
+        logger_func(text, *args[1:])
+
     def debug(self, *args):
         """Log at level DEBUG"""
         self._log(self.logger.debug, *args)
+
     def info(self, *args):
         """Log at level INFO"""
         self._log(self.logger.info, *args)
+
     def warn(self, *args):
         """Log at level WARN"""
         self._log(self.logger.warn, *args)
+
     def error(self, *args):
         """Log at level ERROR"""
         self._log(self.logger.error, *args)
+
     def exception(self, *args):
         """Log an exception"""
         self._log(self.logger.exception, *args)
+
     def note(self, *args):
         """Log at NOTE level (high-priority info) """
         self._log(self.logger.high, *args)
+
     def trace(self, *args):
         """Log at level TRACE"""
         self._log(self.logger.trace, *args)
@@ -125,6 +127,7 @@ class mklog(object):
 LOGFILENAME = os.path.join(LOGFOLDER, 'syncdaemon.log')
 EXLOGFILENAME = os.path.join(LOGFOLDER, 'syncdaemon-exceptions.log')
 INVALIDLOGFILENAME = os.path.join(LOGFOLDER, 'syncdaemon-invalid-names.log')
+BROKENLOGFILENAME = os.path.join(LOGFOLDER, 'syncdaemon-broken-nodes.log')
 
 
 # root logger
@@ -179,6 +182,14 @@ invnames_handler.setFormatter(basic_formatter)
 invnames_handler.setLevel(logging.INFO)
 invnames_logger.addHandler(invnames_handler)
 
+# broken nodes log
+brokennodes_logger = logging.getLogger("ubuntuone.SyncDaemon.BrokenNodes")
+brokennodes_logger.setLevel(_DEBUG_LOG_LEVEL)
+brokennodes_handler = CustomRotatingFileHandler(filename=BROKENLOGFILENAME)
+brokennodes_handler.setFormatter(basic_formatter)
+brokennodes_handler.setLevel(logging.INFO)
+brokennodes_logger.addHandler(brokennodes_handler)
+
 
 def configure_logging(level, maxBytes, backupCount):
     """configure level, maxBytes and backupCount in all handlers"""
