@@ -200,16 +200,6 @@ class FSKey(object):
         """Move file to conflict."""
         self.fs.move_to_conflict(self.get_mdid())
 
-    def refresh_stat(self):
-        """Refresh the stat."""
-        path = self["path"]
-        # pylint: disable-msg=W0704
-        try:
-            self.fs.refresh_stat(path)
-        except OSError:
-            # no file to stat, nothing to do
-            pass
-
     def safe_get(self, key, default='^_^'):
         """Safe version of self.get, to be used in the FileLogger."""
         # catch all errors as we are here to help logging
@@ -1035,7 +1025,8 @@ class Sync(object):
         ssmr.on_event("AQ_MOVE_OK", {}, share_id, node_id)
         ssmr.update_generation(share_id, node_id, new_generation)
 
-    def handle_AQ_MOVE_ERROR(self, share_id, node_id, parent_id, error):
+    def handle_AQ_MOVE_ERROR(self, share_id, node_id, old_parent_id,
+                             new_parent_id, new_name, error):
         """On AQ_MOVE_ERROR."""
         key = FSKey(self.m.fs, share_id=share_id, node_id=node_id)
         log = FileLogger(self.logger, key)
