@@ -481,16 +481,6 @@ class SyncDaemonTool(object):
                            error_handler=d.errback)
         return d
 
-    def query_by_path(self, path):
-        """requesting a query of the node idetifiend by 'path' to the server."""
-        self.log.debug('query_by_path(%s)', path)
-        sd_client = DBusClient(self.bus, '/', DBUS_IFACE_SYNC_NAME)
-        d = defer.Deferred()
-        sd_client.call_method('query_by_path', path,
-                              reply_handler=d.callback,
-                              error_handler=d.errback)
-        return d
-
     def get_metadata(self, path):
         """ calls the exposed mtehod FileSystem.get_metadata using DBus. """
         self.log.debug('get_metadata(%s)', path)
@@ -728,6 +718,45 @@ class SyncDaemonTool(object):
                 self.start()
             return defer.succeed(None)
 
+    def refresh_volumes(self):
+        """Call refresh_volumes method via DBus.
+
+        Request the volumes list to the server.
+        """
+        self.log.debug('refresh_volumes')
+        shares_client = DBusClient(self.bus, '/folders', DBUS_IFACE_FOLDERS_NAME)
+        d = defer.Deferred()
+        shares_client.call_method('refresh_volumes',
+                                  reply_handler=d.callback,
+                                  error_handler=d.errback)
+        return d
+
+    def rescan_from_scratch(self, volume_id):
+        """Call rescan_from_scratch via DBus.
+
+        Request a rescan from scratch for volume_id.
+        """
+        self.log.debug('rescan_from_scratch %r', volume_id)
+        shares_client = DBusClient(self.bus, '/', DBUS_IFACE_SYNC_NAME)
+        d = defer.Deferred()
+        shares_client.call_method('rescan_from_scratch', volume_id,
+                                  reply_handler=d.callback,
+                                  error_handler=d.errback)
+        return d
+
+    def get_dirty_nodes(self):
+        """Call get_dirty_nodes via DBus.
+
+        Return the list of dirty nodes.
+        """
+        self.log.debug('get_dirty_nodes')
+        fs_client = DBusClient(self.bus, '/filesystem', DBUS_IFACE_FS_NAME)
+        d = defer.Deferred()
+        fs_client.call_method('get_dirty_nodes',
+                                  reply_handler=d.callback,
+                                  error_handler=d.errback)
+        return d
+
 
 # callbacks used by u1sdtool script
 
@@ -754,7 +783,8 @@ def show_folders(folders, out):
         out.write("Folder list:\n")
     for folder in folders:
         msg_template = '  id=%s subscribed=%s path=%s\n'
-        out.write(msg_template % (folder['volume_id'], folder['subscribed'],
+        out.write(msg_template % (folder['volume_id'],
+                                  bool(folder['subscribed']),
                                   folder['path']))
 
 
@@ -828,9 +858,29 @@ def show_state(state_dict, out):
 
 
 def show_waiting_metadata(waiting_ops, out):
-    """Print the waiting_metadata result"""
-    for value in waiting_ops:
-        out.write(" %s\n" % value)
+    """Print the waiting_metadata result.
+
+    We receive an unordered dict, but always try to show first the
+    share_id, then the node_id, then the path, and the rest in
+    alphabetical order.
+    """
+    for op_name, op_data in waiting_ops:
+        out.write(' ' + op_name)
+        if not op_data:
+            out.write('\n')
+            continue
+
+        # custom
+        attributes = []
+        for attr in ('share_id', 'node_id', 'path'):
+            if attr in op_data:
+                attributes.append(u"%s='%s'" % (attr, op_data.pop(attr)))
+
+        # the rest, ordered
+        for attr in sorted(op_data):
+            attributes.append(u"%s='%s'" % (attr, op_data[attr]))
+
+        out.write("(%s)\n" % (u', '.join(attributes),))
 
 
 def show_waiting_content(waiting_ops, out):
@@ -848,3 +898,20 @@ def show_public_file_info(file_info, out):
         out.write("File is published at %s\n" % file_info['public_url'])
     else:
         out.write("File is not published\n")
+
+
+def show_dirty_nodes(nodes, out):
+    """Print the list of dirty nodes."""
+    if not nodes:
+        out.write(" No dirty nodes.\n")
+        return
+    out_encoding = out.encoding
+    if out_encoding is None:
+        out_encoding = 'utf-8'
+    node_line_tpl = "mdid: %(mdid)s volume_id: %(share_id)s " + \
+            "node_id: %(node_id)s is_dir: %(is_dir)s path: %(path)s\n"
+    out.write(" Dirty nodes:\n")
+    for node in nodes:
+        node['path'] = node['path'].decode(out_encoding, 'replace')
+        out.write(node_line_tpl % node)
+
