@@ -481,6 +481,10 @@ class VolumeManager(object):
         """Do the 'server rescan'"""
         d = self.m.action_q.query_volumes()
         d.addCallback(self._volumes_rescan_cb)
+        def cleanup(result):
+            shares, udfs = result
+            self._cleanup_volumes(shares=shares, udfs=udfs)
+        d.addCallbacks(cleanup)
         def done(_):
             self.m.event_q.push('SYS_SERVER_RESCAN_DONE')
         def error(failure):
@@ -1235,7 +1239,10 @@ class VolumeManager(object):
 
     def handle_SV_VOLUME_CREATED(self, volume):
         """Handle SV_VOLUME_CREATED event."""
-        self._handle_new_volume(volume)
+        vol = self._handle_new_volume(volume)
+        if vol and vol.active:
+            self.m.action_q.rescan_from_scratch(vol.volume_id)
+
 
     def handle_SV_VOLUME_DELETED(self, volume_id):
         """Handle SV_VOLUME_DELETED event."""
